from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_AVR_Dx = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AVR32DA28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA28x-xSO\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA32x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA32x-xRXB\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA48x-x6LX\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA48x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB28x-xSO\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB32x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB32x-xRXB\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB48x-x6LX\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB48x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA64x-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA64x-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA64x-xMR\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6_',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA64x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA64x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA64x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6_',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB64x-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB64x-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB64x-xMR\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB64x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB64x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB64x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA28x-xSO\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA28x-xSP\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA28x-xSS\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA32x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA32x-xRXB\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA48x-x6LX\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA48x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA64x-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA64x-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA64x-xMR\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6_',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DA64x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DA64x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DA28-32-48-64-DataSheet-DS40002183B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DA64x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6_',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB28x-xSO\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB28x-xSP\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB28x-xSS\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB32x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB32x-xRXB\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB48x-x6LX\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB48x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB64x-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB64x-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB64x-xMR\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR128DB64x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR128DB64x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR128DB28-32-48-64-DataSheet-DS40002247A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR128DB64x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA28x-xSP\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DA28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DA28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DA28-32-48-Data-Sheet-40002228B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DA28x-xSS\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB28x-xSP\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR32DB28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR32DB28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR32DB28-32-48-DataSheet-DS40002301A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR32DB28x-xSS\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA28x-xSO\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA28x-xSP\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA28x-xSS\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA32x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA32x-xRXB\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA48x-x6LX\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DA48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DA48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DA', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DA28-32-48-64-Data-Sheet-40002233B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DA48x-xPT\n\nAVR 8bit Microcontroller AVR-DA', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB28x-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB28x-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB28x-xSO\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB28x-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB28x-xSP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB28x-xSP\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB28x-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB28x-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB28x-xSS\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB32x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB32x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB32x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB32x-xRXB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB32x-xRXB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB32x-xRXB\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}/PF6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB48x-x6LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB48x-x6LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB48x-x6LX\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR64DB48x-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR64DB48x-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller AVR-DB', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/AVR64DB28-32-48-64-DataSheet-DS40002300A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR_Dx.kicad_sym\nAVR64DB48x-xPT\n\nAVR 8bit Microcontroller AVR-DB', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VREFA/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='XTAL32K1/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='XTAL32K2/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}/PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='XTALHF1/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='XTALHF2/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])